summaryrefslogtreecommitdiff
path: root/STALService/src/main/java/at/gv/egiz/stal/service/GetHashDataInputFault.java
diff options
context:
space:
mode:
Diffstat (limited to 'STALService/src/main/java/at/gv/egiz/stal/service/GetHashDataInputFault.java')
-rw-r--r--STALService/src/main/java/at/gv/egiz/stal/service/GetHashDataInputFault.java22
1 files changed, 4 insertions, 18 deletions
diff --git a/STALService/src/main/java/at/gv/egiz/stal/service/GetHashDataInputFault.java b/STALService/src/main/java/at/gv/egiz/stal/service/GetHashDataInputFault.java
index 4db6a91c..df42ab47 100644
--- a/STALService/src/main/java/at/gv/egiz/stal/service/GetHashDataInputFault.java
+++ b/STALService/src/main/java/at/gv/egiz/stal/service/GetHashDataInputFault.java
@@ -1,28 +1,14 @@
-/*
-* Copyright 2008 Federal Chancellery Austria and
-* Graz University of Technology
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-* http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*/
package at.gv.egiz.stal.service;
import javax.xml.ws.WebFault;
+import at.gv.egiz.stal.service.types.GetHashDataInputFaultType;
+
/**
* This class was generated by the JAX-WS RI.
* JAX-WS RI 2.1.3-b02-
- * Generated source version: 2.1
+ * Generated source version: 2.0
*
*/
@WebFault(name = "GetHashDataInputFault", targetNamespace = "http://www.egiz.gv.at/stal")
@@ -60,7 +46,7 @@ public class GetHashDataInputFault
/**
*
* @return
* returns fault bean: at.gv.egiz.stal.GetHashDataInputFaultType
*/
public GetHashDataInputFaultType getFaultInfo() {
return faultInfo;
@@ -60,7 +46,7 @@ public class GetHashDataInputFault
*
* @return
- * returns fault bean: at.gv.egiz.stal.GetHashDataInputFaultType
+ * returns fault bean: at.gv.egiz.stal.service.types.GetHashDataInputFaultType
*/
public GetHashDataInputFaultType getFaultInfo() {